summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorSimon Ser <contact@emersion.fr>2022-09-08 10:36:28 +0200
committerSimon Ser <contact@emersion.fr>2022-09-13 18:01:57 +0000
commit1db6153cc2040849ac4bf38c4660905441e56c01 (patch)
tree3ff35ae2903e545f805e939fe95eef17cbc8003d /src
parent68fef9922edd9add56d97c5bb4d64b6a3179764b (diff)
downloadwayland-1db6153cc2040849ac4bf38c4660905441e56c01.tar.gz
util: name function typedef arguments
Doxygen doesn't support documenting unnamed function arguments. Fixes the following warnings: src/wayland-util.h:697: warning: argument 'const' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'void' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'void' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'uint32_t' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'const' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'struct' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'wl_message' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'union' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'wl_argument' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:725: warning: argument 'const' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) src/wayland-util.h:725: warning: argument 'char' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) src/wayland-util.h:725: warning: argument 'va_list' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) src/wayland-util.h:697: warning: argument 'const' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'void' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'void' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'uint32_t' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'const' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'struct' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'wl_message' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'union' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:697: warning: argument 'wl_argument' of command @param is not found in the argument list of wl_dispatcher_func_t(const void *, void *, uint32_t, const struct wl_message *, union wl_argument *) src/wayland-util.h:725: warning: argument 'const' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) src/wayland-util.h:725: warning: argument 'char' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) src/wayland-util.h:725: warning: argument 'va_list' of command @param is not found in the argument list of wl_log_func_t(const char *, va_list) Signed-off-by: Simon Ser <contact@emersion.fr>
Diffstat (limited to 'src')
-rw-r--r--src/wayland-util.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/wayland-util.h b/src/wayland-util.h
index 4d59231..b4cdcfa 100644
--- a/src/wayland-util.h
+++ b/src/wayland-util.h
@@ -707,17 +707,17 @@ union wl_argument {
* corresponding to the callback. The final argument is an array of arguments
* received from the other process via the wire protocol.
*
* \param "const void *" Dispatcher-specific implementation data
* \param "void *" Callback invocation target (wl_proxy or `wl_resource`)
* \param uint32_t Callback opcode
* \param "const struct wl_message *" Callback message signature
* \param "union wl_argument *" Array of received arguments
*
* \return 0 on success, or -1 on failure
*/
-typedef int (*wl_dispatcher_func_t)(const void *, void *, uint32_t,
- const struct wl_message *,
- union wl_argument *);
+typedef int (*wl_dispatcher_func_t)(const void *user_data, void *target,
+ uint32_t opcode, const struct wl_message *msg,
+ union wl_argument *args);
/**
* Log function type alias
@@ -736,14 +736,14 @@ typedef int (*wl_dispatcher_func_t)(const void *, void *, uint32_t,
* \note Take care to not confuse this with `wl_protocol_logger_func_t`, which
* is a specific server-side logger for requests and events.
*
* \param "const char *" String to write to the log, containing optional format
* specifiers
* \param "va_list" Variable argument list
*
* \sa wl_log_set_handler_client
* \sa wl_log_set_handler_server
*/
-typedef void (*wl_log_func_t)(const char *, va_list) WL_PRINTF(1, 0);
+typedef void (*wl_log_func_t)(const char *fmt, va_list args) WL_PRINTF(1, 0);
/**
* Return value of an iterator function
@@ -707,17 +707,17 @@ union wl_argument {
* received from the other process via the wire protocol.
*
- * \param "const void *" Dispatcher-specific implementation data
- * \param "void *" Callback invocation target (wl_proxy or `wl_resource`)
- * \param uint32_t Callback opcode
- * \param "const struct wl_message *" Callback message signature
- * \param "union wl_argument *" Array of received arguments
+ * \param user_data Dispatcher-specific implementation data
+ * \param target Callback invocation target (wl_proxy or `wl_resource`)
+ * \param opcode Callback opcode
+ * \param msg Callback message signature
+ * \param args Array of received arguments
*
* \return 0 on success, or -1 on failure
@@ -736,14 +736,14 @@ typedef int (*wl_dispatcher_func_t)(const void *, void *, uint32_t,
* is a specific server-side logger for requests and events.
*
- * \param "const char *" String to write to the log, containing optional format
- * specifiers
- * \param "va_list" Variable argument list
+ * \param fmt String to write to the log, containing optional format
+ * specifiers
+ * \param args Variable argument list
*
* \sa wl_log_set_handler_client